<?php
/**
 * WoWRoster.net WoWRoster
 *
 * LICENSE: Licensed under the Creative Commons
 *          "Attribution-NonCommercial-ShareAlike 2.5" license
 *
 * @copyright  2002-2007 WoWRoster.net
 * @license    http://creativecommons.org/licenses/by-nc-sa/2.5   Creative Commons "Attribution-NonCommercial-ShareAlike 2.5"
 * @version    SVN: $Id: search.inc.php 0001 2012-11-19 18:03:00Z Nefuh $
 * @link       http://www.wowroster.net
 * @package    GuildHistory
 * @subpackage Search
 */
 
if( !defined('IN_ROSTER') )
{
    exit('Detected invalid access to this file!');
}
 
/**
 * GuildHistory Search
 *
 * @package    GuildHistory
 * @subpackage Search
 */
class guildhistorySearch
{
	var $options;
	var $result = array();
	var $result_count = 0;
	var $start_search;
	var $stop_search;
	var $time_search;
	var $open_table;
	var $close_table;
	var $search_url;
	var $data = array();    // Addon data
 
	/**
	 * guildhistorySearch::search()
     * 
     * Main search function, which is called by roster
	 * 
	 * @param string $search - search string
	 * @param integer $limit - number of results to display
	 * @param integer $page - number of page that is displayed
	 * @return null
	 */
	function search( $search , $limit=10 , $page=0 )
	{
		global $roster; 
		$first = $page*$limit; // calculate first entrie to get from database
        $search = $roster->db->escape($search); // Escape search string, for security reason
        $search_time = strtotime($search); // Try to convert search string into timestring, so you could also search for a date.
        /*
         * BOF - If $search_time is greater 0 get unix timestamp for day start and day end
         *       so searching within start value and end value will also be done.
         */
        if ($search_time > 0)             
            $search_times = $this->get_times_to_search($search_time);
        /*
         * EOF
         */
		$sql = "SELECT `player1`, `type`, `player2`, `time`, `logtime`, `rank`, `id`, `guild_id` ";
		$sql .= "FROM `" . $roster->db->table('guildhistory','guildhistory') . "`";
		$sql .= "WHERE `player1` LIKE '%$search%' ";
        /*
         * BOF - Try also searching within day start and day end values, if $search_time is not empty and greater 0
         */
        if (!empty($search_time) && $search_time > 0)
        {
            $sql .= "OR (`time` >= ".$search_times['first']." AND `time` <= ".$search_times['last'].") ";
            $sql .= "OR (`logtime` >= ".$search_times['first']." AND `logtime` <= ".$search_times['last'].") ";
        }
        /*
         * EOF
         */
		$sql .= "OR `type` LIKE '%$search%' ";
		$sql .= "OR `player2` LIKE '%$search%' ";
		$sql .= "OR `rank` LIKE '%$search%' ";
		$sql .= " GROUP BY `id` ";
		$sql .= ( $limit > 0 ? " LIMIT $first," . $limit : '' ) . ';';
		//calculating the search time
		$this->start_search = format_microtime();
 		$result = $roster->db->query($sql);
 		$this->stop_search = format_microtime();
		$this->time_search = $this->stop_search - $this->start_search; 
		$nrows = $roster->db->num_rows($result); 
		$x = ($limit > $nrows) ? $nrows : ($limit > 0 ? $limit : $nrows);
        $item['results_header'] = '<table style="width:100%;" cellpadding="2" cellspacing="0"><tr><th class="membersHeader">'.$roster->locale->act['date'].'</th><th class="membersHeader">'.$roster->locale->act['action'].'</th></tr>';
		if( $nrows > 0 )
		{
			while( $x > 0 )
			{
				list($player1, $type, $player2, $time, $logtime, $rank, $id, $guild_id) = $roster->db->fetch($result);
                $item['html'] = '<tr>
                                    <td class="membersRow1">'.date($roster->locale->act['guildhistory_dateformat'], $logtime).'</td>
                                    <td class="membersRow1">'.$player1.' '.$roster->locale->act[$type].' '.$player2.' '.(($type == 'remove' || $type == 'invite') ? null : $roster->locale->act['to'].'&nbsp;'.$rank).'</td>
                                </tr>'."\n";
                $item['html'] = str_replace($search, '<span style="text-decoration:underline;">'.$search.'</span>', $item['html']);
                $link_time = mktime(0,0,0,date('n', $logtime),date('j', $logtime),date('Y', $logtime));
				$item['url'] = makelink('guild-guildhistory&amp;logtime='.$link_time); 
				$this->add_result($item);
				unset($item);
				$x--;
			}
		}
        $item['results_footer'] = '</table>'."\n";
		$roster->db->free_result($result);
	}

    /**
     * guildhistorySearch::get_times_to_search()
     * 
     * Helper function to get unix timestamps for day start and day end.
     * 
     * @param integer $stime - unix timestamp
     * @return array $search_time - The start and end timestamp for searched day
     */
    function get_times_to_search($stime)
    {
        $day = date('j', $stime);
        $month = date('n', $stime);
        $year = date('Y', $stime);
        $hour = date('H', $stime);
        $minute = date('i', $stime);
        $second = date('s', $stime);
        $search_time['first'] = mktime(0,0,0, $month, $day, $year);
        $search_time['last'] = mktime(23,59,59, $month, $day, $year);
        return $search_time;        
    }

 
	/**
	 * guildhistorySearch::add_result()
     * 
     * Function to throw out, the search results
	 * 
	 * @param mixed $resultarray
	 * @return null
	 */
	function add_result( $resultarray )
	{
		$this->result[$this->result_count++] = $resultarray;
	}
}