<?php
/**
 * WoWRoster.net WoWRoster
 *
 * LICENSE: Licensed under the Creative Commons
 *          "Attribution-NonCommercial-ShareAlike 2.5" license
 *
 * @copyright  2002-2007 WoWRoster.net
 * @license    http://creativecommons.org/licenses/by-nc-sa/2.5   Creative Commons "Attribution-NonCommercial-ShareAlike 2.5"
 * @version    SVN: $Id: update_hook.php 1705 2012-11-19 19:41:00Z Nefuh $
 * @link       http://www.wowroster.net
 * @package    GuildHistory
 * @subpackage UpdateHook
*/

if ( !defined('IN_ROSTER') )
    exit('Detected invalid access to this file!');

/**
 * GuildHistory Update Hook
 *
 * @package    GuildHistory
 * @subpackage UpdateHook
 */
class guildhistoryUpdate
{
	// Update messages
	var $messages = '';

	// Addon data object, recieved in constructor
	var $data;

	// LUA upload files accepted. We don't use any.
	var $files = array();
	var $timestamp = '';

	/**
	 * Constructor
	 *
	 * @param array $data
	 *		Addon data object
	 */
	function __construct($data)
	{
		$this->data = $data;
	}

	/**
	 * Resets addon messages
	 */
	function reset_messages()
	{
        global $roster;
		/**
		 * We display the addon name at the beginning of the output line. If
		 * the hook doesn't exist on this side, nothing is output. If we don't
		 * produce any output (update method off) we empty this before returning.
		 */

		$this->messages = '<li>'.$roster->locale->act['guildhistory'].'<ul>';
	}

	/**
	 * Guild post trigger
	 *
	 * @param array $guild
	 *		CP.lua guild data
	 */
	function guild_post($guild)
	{
		global $roster, $addon;
        $addon_config = $this->get_addon_config();
		if ( (isset($guild['EventLog'])) && (is_array($guild['EventLog'])) )
		{
            $last_logtime = $this->get_last_logtime(); 
            $num_entries = sizeof($guild['EventLog']);       
			for ($id = 1; $id <= sizeof($guild['EventLog']); $id++) 
			{
		  		$string = '<li>'.$roster->locale->act['processing_line'];
			  	$string = str_replace('%1', $id, $string);
                $string = str_replace('%2', $num_entries, $string);
                $this->messages .= $string;
                $this->timestamp = $guild['EventLog'][$id]['Time'];
			  	$time = $this->make_time($guild['EventLog'][$id]['LogTime']);
                if ($time[0] > $last_logtime)
                {
				  	$query = "INSERT INTO `".$roster->db->table('guildhistory', $this->data['basename'])."` (
                             `guild_id`, 
                             `id`, 
                             `player1`, 
                             `type`, 
                             `player2`, 
                             `time`, 
                             `logtime`, 
                             `rank`
                             ) VALUES (
                             '".$guild['guild_id']."', 
                             '".$id."', 
                             '".$guild['EventLog'][$id]['Player1']."', 
                             '".$guild['EventLog'][$id]['Type']."', 
                             '".$guild['EventLog'][$id]['Player2']."',
                             '".$guild['EventLog'][$id]['Time']."', 
                             '".$time[0]."', 
                             '".$guild['EventLog'][$id]['Rank']."')";
                    $roster->db->free_result($result);
				    if ($roster->db->query($query)) 
                        $this->messages .= '<font color="#00FF00">'.$roster->locale->act['added'].'</font></li>'."\n";
                    else 
                        $this->messages .= '<font color="#FF0000">'.$roster->locale->act['failed'].'!</font></li>'."\n";
                }
                else
                    $this->messages .= '<font color="#FFFF00">'.$roster->locale->act['outdated'].'</font></li>'."\n";
            }
			$this->messages .= '</ul></li>';
            if ($addon_config['guildhistory_autopurge'] > 0)
                $this->purge_data($addon_config['guildhistory_autopurge'], $guild['guild_id']);
			return true;
		}
		else
		{
		  	$this->messages .= '<li><font color="#0000FF">'.$lang['guildhistory_no_data'].'</font></li>';
		  	return true;
		}
	}
    
    /**
     * guildhistoryUpdate::purge_data()
     * 
     * Function to purge old data from database
     * 
     * @param mixed $pot
     * @param mixed $gid
     * @return void
     */
    function purge_data($pot, $gid)
    {
        global $roster;
        $latest_logtime = $this->get_latest_logtime($pot);
        $this->messages .= '<li>'.str_replace('%1', date($roster->locale->act['guildhistory_datetimeformat'], $latest_logtime), $roster->locale->act['purge_records_older_than']).'<ul>';
        $sql = "SELECT `id` FROM `".$roster->db->table('guildhistory', $this->data['basename'])."` WHERE `guild_id` = '".$gid."' AND `logtime` <= '".$latest_logtime."';";
        $result = $roster->db->query($sql);
        $records_to_purge = $roster->db->num_rows($result);
        if ($records_to_purge > 0)
        {
            $sql = "DELETE FROM `".$roster->db->table('guildhistory', $this->data['basename'])."` WHERE `guild_id` = '".$gid."' AND `logtime` <= '".$latest_logtime."';";
            if ($roster->db->query($sql)) $this->messages .= '<li>'.str_replace('%1', $records_to_purge, $roster->locale->act['purged_records']).'</li>';
            else $this->messages .= '<li>'.str_replace('%1', $records_to_purge, $roster->locale->act['failed_purging_records']).'</li>';
        }
        else 
            $this->messages .= '<li>'.$roster->locale->act['no_records_to_purge'].'</li>';
        $this->messages .= '</ul></li>'."\n";        
    }
    
    /**
     * guildhistoryUpdate::get_latest_logtime()
     * 
     * Function to get the latest_logtime that will be available in database, after purging data
     * 
     * @param mixed $pot
     * @return integer $lastest_logtime - unix timestamp
     */
    function get_latest_logtime($pot)
    {
        $last_logtime = $this->get_last_logtime();
        $day = date('j', $last_logtime);
        $month = date('n', $last_logtime);
        $year = date('Y', $last_logtime);
        $hour = date('H', $last_logtime);
        $minute = date('i', $last_logtime);
        $second = date('s', $last_logtime);
        $latest_logtime = mktime($hour, $minute, $second, $month - $pot, $day, $year);
        return $latest_logtime;        
    }
    
    /**
     * guildhistoryUpdate::get_last_logtime()
     * 
     * Function to get the latest logtime from database.
     * 
     * @return integer $data['logtime'] - unix timestamp
     */
    function get_last_logtime()
    {
        global $roster;
        $sql = "SELECT `logtime` FROM `".$roster->db->table('guildhistory', $this->data['basename'])."` ORDER BY `logtime` DESC";
        $result = $roster->db->query($sql);
        $data = $roster->db->fetch($result);
        return $data['logtime'];
    }
    
    /**
     * guildhistoryUpdate::get_addon_config()
     * 
     * Function to get addon configuration from database
     * 
     * @return array $addon_config - Array of addon configuration values
     */
    function get_addon_config()
    {
        global $roster;
        $sql = "SELECT `addon_id` FROM `".$roster->db->table('addon')."` WHERE `basename` = '".$this->data['basename']."';";
        $result = $roster->db->query($sql);
        $data = $roster->db->fetch($result);
        $addon_id = $data['addon_id'];
        $sql = "SELECT `config_name`, `config_value` FROM `".$roster->db->table('addon_config')."` WHERE `addon_id` = '".$addon_id."';";
        $result = $roster->db->query($sql);
        while ($data = $roster->db->fetch($result))
            $addon_config[$data['config_name']] = $data['config_value'];
        #$this->messages .= 'CFG: '.print_r($addon_config, true).'<br />';
        return $addon_config;
    }

	/**
	 * guildhistoryUpdate::make_time()
	 * 
	 * @param mixed $time
	 * @return array - getDate() - Array of date values for give date
	 */
	function make_time( $time )
	{
		global $update;
		list($lastOnlineYears,$lastOnlineMonths,$lastOnlineDays,$lastOnlineHours) = explode(':',$time);
		$timeString = '-';
		if ($lastOnlineYears > 0)
			$timeString .= $lastOnlineYears . ' Years ';
		if ($lastOnlineMonths > 0)
			$timeString .= $lastOnlineMonths . ' Months ';
		if ($lastOnlineDays > 0)
			$timeString .= $lastOnlineDays . ' Days ';
		$timeString .= max($lastOnlineHours,1) . ' Hours';
		$lastOnlineTime = strtotime($timeString,$this->timestamp);
		return getDate($lastOnlineTime);
	}
}